==> Zephyrus-2.7.3.10201.tar.gz: Zephyrus-2.7.3.10201/Zephyrus/boilerplate/management/commands/fix_template.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: fix_template.py 10200 2017-08-20 02:49:07Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
# $Revision: 10200 $

import os
import shutil
import hashlib

from django.core.management.base import BaseCommand, CommandError
from django.conf import settings
from cms.templatetags.cms_tags import *

from Zephyrus.boilerplate.management.commands import TEMPLATES_DIR_PATH
from Zephyrus.boilerplate.management.commands import cerateLogger

logger = cerateLogger(__name__, "FixTemplate.log")
            
class Command(BaseCommand):
    
    help = 'Fix template to no endplaceholder.'
    
    def add_arguments(self, parser):
        parser.add_argument(
            '--overwrite',
            default=False,
            help='Overwrite html or create new html file name xxxFix.html.',
        )
    
    def handle(self, *args, **options):
        from django import template
        from django.template import Context
            
        fileList = os.listdir(TEMPLATES_DIR_PATH)
        for file in fileList:
            file = os.path.join(TEMPLATES_DIR_PATH, file)
            logger.info(file)
            # preprocess
            loadTagHash = hashlib.md5(
                "{% load cms_tags menu_tags sekizai_tags %}"
                "{% load staticfiles %}").hexdigest()
            jsHash = "%s" % hashlib.md5(
                "{% render_block 'js' %}").hexdigest()
            cssHash = "%s" % hashlib.md5(
                "{% render_block 'css' %}").hexdigest()
            toolbarHash = "%s" % hashlib.md5(
                "{% cms_toolbar %}").hexdigest()
            with open(file, 'r') as f:
                text = f.read()
                text = text.replace(
                    "{% load cms_tags menu_tags sekizai_tags %}"
                    "{% load staticfiles %}", 
                    "{% load FakeTemplateTags %}" + loadTagHash)
                text = text.replace("{% render_block 'css' %}", cssHash)
                text = text.replace("{% render_block 'js' %}", jsHash)
                text = text.replace("{% cms_toolbar %}", toolbarHash)
                
            if options['overwrite']:
                fileName = file
            else:
                index = file.index('.html')
                fileName = file[:index] + '_user.html'
                
           
            with open(fileName, 'w') as f:
                f.write(text)
           
            # process
            with open(fileName) as f:
                t = template.Template(f.read())
                replaceStr = Context({})
                
                text = t.render(replaceStr)
                
            # endprocess
            text = text.replace(
                loadTagHash, 
                "{% load cms_tags menu_tags sekizai_tags %}"
                "{% load staticfiles %}")
            text = text.replace(jsHash, "{% render_block 'js' %}")
            text = text.replace(cssHash, "{% render_block 'css' %}")
            text = text.replace(toolbarHash, "{% cms_toolbar %}")
            with open(fileName, 'w') as f:
                f.write(text)

==> Zephyrus-2.9.6.10313.tar.gz: Zephyrus-2.9.6.10313/Zephyrus/boilerplate/management/commands/fix_template.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: fix_template.py 10213 2017-08-22 09:34:20Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
# $Revision: 10213 $

import os
import shutil
import hashlib

from django.core.management.base import BaseCommand, CommandError
from django.conf import settings
from cms.templatetags.cms_tags import *

from Zephyrus.boilerplate.management.commands import TEMPLATES_DIR_PATH
from Zephyrus.boilerplate.management.commands import createLogger

logger = createLogger(__name__, "FixTemplate.log")
            
class Command(BaseCommand):
    
    help = 'Fix template to no endplaceholder.'
    
    def add_arguments(self, parser):
        parser.add_argument(
            '--overwrite',
            default=False,
            help='Overwrite html or create new html file name xxxFix.html.',
        )
    
    def handle(self, *args, **options):
        from django import template
        from django.template import Context
            
        fileList = os.listdir(TEMPLATES_DIR_PATH)
        for file in fileList:
            file = os.path.join(TEMPLATES_DIR_PATH, file)
            logger.info(file)
            # preprocess
            loadTagHash = hashlib.md5(
                "{% load cms_tags menu_tags sekizai_tags %}"
                "{% load staticfiles %}").hexdigest()
            jsHash = "%s" % hashlib.md5(
                "{% render_block 'js' %}").hexdigest()
            cssHash = "%s" % hashlib.md5(
                "{% render_block 'css' %}").hexdigest()
            toolbarHash = "%s" % hashlib.md5(
                "{% cms_toolbar %}").hexdigest()
            with open(file, 'r') as f:
                text = f.read()
                text = text.replace(
                    "{% load cms_tags menu_tags sekizai_tags %}"
                    "{% load staticfiles %}", 
                    "{% load FakeTemplateTags %}" + loadTagHash)
                text = text.replace("{% render_block 'css' %}", cssHash)
                text = text.replace("{% render_block 'js' %}", jsHash)
                text = text.replace("{% cms_toolbar %}", toolbarHash)
                
            if options['overwrite']:
                fileName = file
            else:
                index = file.index('.html')
                fileName = file[:index] + '_user.html'
                
           
            with open(fileName, 'w') as f:
                f.write(text)
           
            # process
            with open(fileName) as f:
                t = template.Template(f.read())
                replaceStr = Context({})
                
                text = t.render(replaceStr)
                
            # endprocess
            text = text.replace(
                loadTagHash, 
                "{% load cms_tags menu_tags sekizai_tags %}"
                "{% load staticfiles %}")
            text = text.replace(jsHash, "{% render_block 'js' %}")
            text = text.replace(cssHash, "{% render_block 'css' %}")
            text = text.replace(toolbarHash, "{% cms_toolbar %}")
            with open(fileName, 'w') as f:
                f.write(text)
